/*
 * Copyright (c) 2009, 2016, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#import "CGColorUtilities.h"

CGColorRef WB_CGColorCreateCalibratedRGB(CGFloat red, CGFloat green, CGFloat blue, CGFloat alpha)
{
	NSColor* calibratedNSColor = [NSColor colorWithCalibratedRed: red
                                                         green: green
                                                          blue: blue
                                                         alpha: alpha];
	
	NSColor* deviceColor = [calibratedNSColor colorUsingColorSpaceName: NSCalibratedRGBColorSpace];
	CGFloat colorComponents[4];
	[deviceColor getRed: &colorComponents[0]
                green: &colorComponents[1]
                 blue: &colorComponents[2]
                alpha: &colorComponents[3]];
	
	CGColorSpaceRef cgColorSpace = CGColorSpaceCreateDeviceRGB();
	CGColorRef calibratedCGColor = CGColorCreate(cgColorSpace, colorComponents);
	CGColorSpaceRelease(cgColorSpace);
  
	return calibratedCGColor;
}


